@@ -40,6 +40,7 @@ from starlette.websockets import WebSocket, WebSocketDisconnect
 from yarl import URL
 
 from satori.const import Api, EventType
+from satori.exception import ActionFailed
 from satori.model import Event, Meta, ModelBase, Opcode
 from satori.utils import decode
 
@@ -96,6 +97,9 @@ async def _request_handler(action: str, request: StarletteRequest, func: RouteCa
                 self_id=self_id,
             )
         )
+    except ActionFailed as ae:
+        logger.warning(ae)
+        return Response(status_code=ae.CODE, content=str(ae))
     except Exception as e:
         logger.error(e)
         return Response(status_code=500, content=str(e))
@@ -139,7 +143,6 @@ class Server(Service, RouterMixin):
         self.port = port
         self.version = version
         self.path = path
-        self.uvicorn_options = uvicorn_options
         if self.path and not self.path.startswith("/"):
             self.path = f"/{self.path}"
         if (self.host == "0.0.0.0" or self.host == "::") and not token:
@@ -157,9 +160,13 @@ class Server(Service, RouterMixin):
         self.stream_chunk_size = stream_chunk_size
         self.resources: dict[str, Path] = {}
         self.app = Starlette()
-        self.asgi_service = UvicornASGIService(self.host, self.port, options=self.uvicorn_options)
+        self.asgi_service = UvicornASGIService(self.host, self.port, options=uvicorn_options)
         super().__init__()
 
+    @property
+    def uvicorn_options(self) -> UvicornOptions:
+        return self.asgi_service.options
+
     def replace_app(self, app: ASGIApp | asgitypes.ASGI3Application):
         """替换当前的 Starlette 应用"""
         self.app = app
